@@ -55,16 +55,16 @@ var applyCommand = &cli.Command{
 		redactFlag,
 		retryIntervalFlag,
 		retryTimeoutFlag,
+		ignoredUpgradeCheckFlag,
 		analyticsFlag,
-		upgradeCheckFlag,
 	},
-	Before: actions(initLogging, startCheckUpgrade, initConfig, initManager, displayLogo, initAnalytics, displayCopyright, warnOldCache),
-	After:  actions(reportCheckUpgrade, closeAnalytics),
+	Before: actions(initLogging, initConfig, initManager, displayLogo, initAnalytics, displayCopyright, warnOldCache),
+	After:  actions(closeAnalytics),
 	Action: func(ctx *cli.Context) error {
 		var kubeconfigOut io.Writer
 
 		if kc := ctx.String("kubeconfig-out"); kc != "" {
-			out, err := os.OpenFile(kc, os.O_CREATE|os.O_WRONLY, 0600)
+			out, err := os.OpenFile(kc, os.O_CREATE|os.O_WRONLY, 0o600)
 			if err != nil {
 				return fmt.Errorf("failed to open kubeconfig-out file: %w", err)
 			}
