@@ -22,6 +22,10 @@ var versionCommand = &cli.Command{
 			Name:  "k0s",
 			Usage: "Retrieve the latest k0s version number",
 		},
+		&cli.BoolFlag{
+			Name:  "k0sctl",
+			Usage: "Retrieve the latest k0sctl version number",
+		},
 		&cli.BoolFlag{
 			Name:  "pre",
 			Usage: "When used in conjunction with --k0s, a pre release is accepted as the latest version",
@@ -37,6 +41,15 @@ var versionCommand = &cli.Command{
 			os.Exit(0)
 		}
 
+		if ctx.Bool("k0sctl") {
+			v, err := github.LatestRelease(ctx.Bool("pre"))
+			if err != nil {
+				return err
+			}
+			fmt.Println(v.TagName)
+			os.Exit(0)
+		}
+
 		if ctx.Bool("machine-id") {
 			id, err := analytics.MachineID()
 			if err != nil {
