@@ -2,11 +2,12 @@ package phase
 
 import (
 	"fmt"
+	"strconv"
+	"time"
 
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1"
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
 	"github.com/k0sproject/rig/exec"
-	"github.com/sirupsen/logrus"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -59,17 +60,21 @@ func (p *DownloadK0s) Run() error {
 }
 
 func (p *DownloadK0s) downloadK0s(h *cluster.Host) error {
-	tmp, err := h.Configurer.TempFile(h)
-	if err != nil {
-		return fmt.Errorf("failed to create tempfile %w", err)
-	}
+	tmp := h.Configurer.K0sBinaryPath() + ".tmp." + strconv.Itoa(int(time.Now().UnixNano()))
 
 	log.Infof("%s: downloading k0s %s", h, p.Config.Spec.K0s.Version)
-	if err := h.Configurer.DownloadK0s(h, tmp, p.Config.Spec.K0s.Version, h.Metadata.Arch); err != nil {
+	if h.K0sDownloadURL != "" {
+		expandedURL := h.ExpandTokens(h.K0sDownloadURL, p.Config.Spec.K0s.Version)
+		log.Infof("%s: downloading k0s binary from %s", h, expandedURL)
+		if err := h.Configurer.DownloadURL(h, expandedURL, tmp, exec.Sudo(h)); err != nil {
+			return fmt.Errorf("failed to download k0s binary: %w", err)
+		}
+	} else if err := h.Configurer.DownloadK0s(h, tmp, p.Config.Spec.K0s.Version, h.Metadata.Arch, exec.Sudo(h)); err != nil {
 		return err
 	}
+
 	if err := h.Execf(`chmod +x "%s"`, tmp, exec.Sudo(h)); err != nil {
-		logrus.Warnf("%s: failed to chmod k0s temp binary: %v", h, err.Error())
+		log.Warnf("%s: failed to chmod k0s temp binary: %v", h, err.Error())
 	}
 
 	h.Metadata.K0sBinaryTempFile = tmp
