@@ -1,7 +1,11 @@
 package v1beta1
 
 import (
-	validation "github.com/go-ozzo/ozzo-validation/v4"
+	"fmt"
+
+	"github.com/creasty/defaults"
+	"github.com/jellydator/validation"
+
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
 )
 
@@ -36,6 +40,10 @@ func (c *Cluster) UnmarshalYAML(unmarshal func(interface{}) error) error {
 		return err
 	}
 
+	if err := defaults.Set(c); err != nil {
+		return fmt.Errorf("failed to set defaults: %w", err)
+	}
+
 	return nil
 }
 
